
clear all
use "data/processed/data_votechange.dta",clear

*---------------------------------------------------------------------------------------
* DEFINE MACROS FOR OPTIONS & SPECIFICATIONS
*---------------------------------------------------------------------------------------

// variables
local x 	RIpit RIvat Dwagetax_av Dvat
local x2 	Dwagetax_50 Dwagetax_100 Dwagetax_150 Dwagetax_200 Dwagetax_pc Dwagetax_rc
local addx	Dtaxrevenue Dcorptax
local int 	left right clarity_dum high_pressure
global cntrl days vote_share effnum_party unemp_avg Dunemp realgdpgr_avg Drealgdpgr deficit_y1 debt_y1

// model setup 
global modelopts 	cluster(gov_id) absorb(iso3n) reps($simrep_boot)
	
// outreg2
local xvarlist
foreach v in `x' `x2' `addx' {
    local xvarlist `xvarlist' `v' `v'_inc `v'_dec `v'_sh `v'_sh_inc `v'_sh_dec
}
local interactlist
foreach v in `xvarlist' {
    foreach i in `int' {
		local interactlist `interactlist' c.`v'#c.`i'
	}
}
glob outregopts auto(2) label ctitle(" ") adjr2 drop(time_*) sortvar(`xvarlist' `interactlist' `int' $cntrl )

// create inverted condition variables 
foreach ff in `int' {
	gen not_`ff' = 1-`ff'
}

*---------------------------------------------------------------------------------------
* DEFINE COMMAND FOR REGRESSION ESTIMATIONS
*---------------------------------------------------------------------------------------

capture program drop r
program r
	syntax , Yvar(string) Xvar(string) MOPTS(string) STORE(string) [RIGHTVar(string) CONTrol(string) CONDition(string) alttimefe]
	
	// count groups
	preserve 
	egen _rm = rowmiss(`yvar' `xvar' `control')
	keep if _rm==0
	gegen partycount = tag(party_id)
	count if partycount==1
	local pcount = r(N)
	gegen electioncount = tag(iso3n edate)
	count if electioncount==1
	local ecount = r(N)
	gegen countrycount = tag(iso3n)
	count if countrycount==1
	local ccount = r(N)
	restore
	
	// set up varying options  
	if "`alttimefe'"=="" local timefe i.time_fe 
	if "`alttimefe'"!="" local timefe i.time_fealt
	if "`rightvar'"=="" local rightvar right
	
	// main regressions
	wildboot areg `yvar' `xvar' `control' `timefe' `condition' [w=cabparties_w], `mopts'
	outreg2 using "results/tables/`store'_`xvar'_main.doc", replace $outregopts addtext(No. parties,`pcount',No. governments,`ecount',No. countries,`ccount',Period FE,Yes)
	est save "results/estimates/`store'_`xvar'_m1", replace
	
	wildboot areg `yvar' `xvar'_dec `xvar'_inc `control' `timefe' `condition' [w=cabparties_w], `mopts'
	outreg2 using "results/tables/`store'_`xvar'_main.doc", append $outregopts addtext(No. parties,`pcount',No. governments,`ecount',No. countries,`ccount',Period FE,Yes)
	est save "results/estimates/`store'_`xvar'_m2", replace
	
	// short term changes
	local no = 1
	wildboot areg `yvar' `xvar'_sh `control' `timefe' `condition' [w=cabparties_w], `mopts'
	outreg2 using "results/tables/`store'_`xvar'_main.doc", append $outregopts addtext(No. parties,`pcount',No. governments,`ecount',No. countries,`ccount',Period FE,Yes)
	est save "results/estimates/`store'_`xvar'_l`no'", replace

	local no2 = `no'+1
	wildboot areg `yvar' `xvar'_sh_dec `xvar'_sh_inc `control' `timefe' `condition' [w=cabparties_w], `mopts' 
	outreg2 using "results/tables/`store'_`xvar'_main.doc", append $outregopts addtext(No. parties,`pcount',No. governments,`ecount',No. countries,`ccount',Period FE,Yes)
	est save "results/estimates/`store'_`xvar'_l`no2'", replace

	// binary "most likely cases"
	local replace replace

	foreach cond_int in left `rightvar' clarity_dum high_pressure { 
		local no = `no'+2
		if !(`"`condition'"'=="if `cond_int'==1") {
			wildboot areg `yvar' c.`xvar'##c.`cond_int' `control' `timefe' `condition' [w=cabparties_w], `mopts'
			outreg2 using "results/tables/`store'_`xvar'_interact.doc", `replace' $outregopts addtext(No. parties,`pcount',No. governments,`ecount',No. countries,`ccount',Period FE,Yes)
			gen `xvar'`no' = `xvar'
			wildboot areg `yvar' c.`xvar'`no' c.not_`cond_int' c.not_`cond_int'#c.`xvar'`no' `control' `timefe' `condition' [w=cabparties_w], `mopts' 
			est save "results/estimates/`store'_`xvar'_l`no'", replace
			
			local no2 = `no'+1
			wildboot areg `yvar' c.`xvar'_dec##c.`cond_int' `xvar'_inc c.`xvar'_inc#c.`cond_int' `control' `timefe' `condition' [w=cabparties_w], `mopts' 
			outreg2 using "results/tables/`store'_`xvar'_interact.doc", append $outregopts addtext(No. parties,`pcount',No. governments,`ecount',No. countries,`ccount',Period FE,Yes)
			qui gen `xvar'_dec`no2' = `xvar'_dec
			qui gen `xvar'_inc`no2' = `xvar'_inc
			qui wildboot areg `yvar' c.`xvar'_dec`no2' c.not_`cond_int' c.not_`cond_int'#c.`xvar'_dec`no2' `xvar'_inc`no2' c.not_`cond_int'#c.`xvar'_inc`no2' `control' `timefe' `condition' [w=cabparties_w], `mopts' 
			est save "results/estimates/`store'_`xvar'_l`no2'", replace
			
			local replace append
		}
	}
	
	foreach dropno of numlist 1/`no2' {
		cap drop `xvar'`dropno'
		cap drop `xvar'_inc`dropno' `xvar'_dec`dropno'
	}
end


*---------------------------------------------------------------------------------------
* ESTIMATE MAIN REGRESSIONS IN PAPER
*---------------------------------------------------------------------------------------

// Main specifications
foreach var in RIpit RIvat Dwagetax_av Dvat {
	r, y(votechange) x(`var') cont($cntrl) mopts($modelopts) store(mainspec)
}

// disaggregated wage tax measures
local count = 1
local tabversion = 0
foreach var in Dwagetax_50 Dwagetax_100 Dwagetax_150 Dwagetax_200 Dwagetax_pc Dwagetax_rc {
	if inlist(`count',1,4) {
		local replace replace 
		local ++tabversion
	}
	else {
		local replace append 
	}
	
	wildboot areg votechange `var' $cntrl i.time_fe [w=cabparties_w], $modelopts
	outreg2 using "results/tables/wagetax_disaggregated_`tabversion'.doc", `replace' $outregopts
	est save "results/estimates/altrates_`var'_m1", replace
	
	wildboot areg votechange `var'_dec `var'_inc $cntrl i.time_fe [w=cabparties_w], $modelopts 
	outreg2 using "results/tables/wagetax_disaggregated_`tabversion'.doc", append $outregopts
	est save "results/estimates/altrates_`var'_m2", replace
	
	local ++count
}

// testing alternative wage tax measures against eachother
wildboot areg votechange Dwagetax_50_dec Dwagetax_200_dec Dwagetax_50_inc Dwagetax_200_inc $cntrl i.time_fe [w=cabparties_w], $modelopts 
outreg2 using "results/tables/wagetax_multi.doc", replace $outregopts
est save "results/estimates/wagetax_multi1", replace

wildboot areg votechange Dwagetax_pc_dec Dwagetax_rc_dec Dwagetax_pc_inc Dwagetax_rc_inc $cntrl i.time_fe [w=cabparties_w], $modelopts 
outreg2 using "results/tables/wagetax_multi.doc", append $outregopts
est save "results/estimates/wagetax_multi2", replace


*---------------------------------------------------------------------------------------
* ESTIMATE ROBUSTNESS CHECKS FOR APPENDIX
*---------------------------------------------------------------------------------------	

// percent change dependent variable 
foreach var in RIpit RIvat Dwagetax_av Dvat {
	r, y(votechange_pc) cont($cntrl)  x(`var') mopts($modelopts) store(r_pcdv)
}

// no control variables 
foreach var in RIpit RIvat Dwagetax_av Dvat {
	r, y(votechange) x(`var') mopts($modelopts) store(r_nox)
}

// SEs clustered by parties
foreach var in RIpit RIvat Dwagetax_av Dvat {
	r, y(votechange) x(`var') cont($cntrl) mopts(cluster(party_id) absorb(iso3n) reps($simrep_boot)) store(r_pclust)
}

// SEs clustered by countries
foreach var in RIpit RIvat Dwagetax_av Dvat {
	r, y(votechange) x(`var') cont($cntrl) mopts(cluster(iso3n) absorb(iso3n) reps($simrep_boot)) store(r_cclust)
}

// alternative time FEs
foreach var in RIpit RIvat Dwagetax_av Dvat {
	r, y(votechange) x(`var') cont($cntrl) mopts($modelopts) alttimefe store(r_time)
}

// un-winsored variables
foreach var in RIpit_og RIvat_og Dwagetax_av_og Dvat_og {
	r, y(votechange_og) x(`var') cont(days_og vote_share_og effnum_party_og unemp_avg_og Dunemp_og realgdpgr_avg_og Drealgdpgr_og deficit_y1_og debt_y1_og) mopts($modelopts) store(r_ogvars)
}

// tax revenue and corporate taxation placebo tests
foreach var in Dtaxrevenue Dcorptax {
	r, y(votechange) cont($cntrl)  x(`var') mopts($modelopts) store(r_corprev)
}

// using collapsed dataset 
glob opts_collapsed $cntrl i.time_fe, cluster(iso3n) absorb(iso3n) reps($simrep_boot)
cap frame drop collapsed
frame create collapsed 
frame collapsed {
	use "data/processed/data_votechange_collapsed.dta", clear
	foreach xvarr in RIpit RIvat Dwagetax_av Dvat Dtaxrevenue Dcorptax {
		wildboot areg votechange `xvarr' $opts_collapsed 
		est save "results/estimates/r_collapse_`xvarr'_m1", replace
		wildboot areg votechange `xvarr'_inc `xvarr'_dec $opts_collapsed
		est save "results/estimates/r_collapse_`xvarr'_m2", replace
		
		wildboot areg votechange `xvarr'_sh $opts_collapsed
		est save "results/estimates/r_collapse_`xvarr'_l1", replace
		wildboot areg votechange `xvarr'_sh_inc `xvarr'_sh_dec $opts_collapsed
		est save "results/estimates/r_collapse_`xvarr'_l2", replace
	}
}
frame drop collapsed

// testing alternative wage tax measures against eachother - comparison to average rather than high
wildboot areg votechange Dwagetax_50_dec Dwagetax_100_dec Dwagetax_50_inc Dwagetax_100_inc $cntrl i.time_fe [w=cabparties_w], $modelopts coef(Dwagetax_50_dec Dwagetax_100_dec Dwagetax_50_inc Dwagetax_100_inc)
est save "results/estimates/wagetax_multi_r_av_1", replace

wildboot areg votechange Dwagetax_pc_dec Dwagetax_ac_dec Dwagetax_pc_inc Dwagetax_ac_inc $cntrl i.time_fe [w=cabparties_w], $modelopts coef(Dwagetax_pc_dec Dwagetax_ac_dec Dwagetax_pc_inc Dwagetax_ac_inc)
est save "results/estimates/wagetax_multi_r_av_2", replace

// testing alternative wage tax measures against eachother - percent dependent variable
wildboot areg votechange_pc Dwagetax_50_dec Dwagetax_200_dec Dwagetax_50_inc Dwagetax_200_inc $cntrl i.time_fe [w=cabparties_w], $modelopts coef(Dwagetax_50_dec Dwagetax_200_dec Dwagetax_50_inc Dwagetax_200_inc)
est save "results/estimates/wagetax_multi_r_pcdv_1", replace

wildboot areg votechange_pc Dwagetax_pc_dec Dwagetax_rc_dec Dwagetax_pc_inc Dwagetax_rc_inc $cntrl i.time_fe [w=cabparties_w], $modelopts coef(Dwagetax_pc_dec Dwagetax_rc_dec Dwagetax_pc_inc Dwagetax_rc_inc)
est save "results/estimates/wagetax_multi_r_pcdv_2", replace

// testing alternative wage tax measures against eachother - standard errors 1
wildboot areg votechange Dwagetax_50_dec Dwagetax_200_dec Dwagetax_50_inc Dwagetax_200_inc $cntrl i.time_fe [w=cabparties_w], cluster(party_id) absorb(iso3n) reps($simrep_boot) coef(Dwagetax_50_dec Dwagetax_200_dec Dwagetax_50_inc Dwagetax_200_inc)
est save "results/estimates/wagetax_multi_r_pclust_1", replace

wildboot areg votechange Dwagetax_pc_dec Dwagetax_rc_dec Dwagetax_pc_inc Dwagetax_rc_inc $cntrl i.time_fe [w=cabparties_w], cluster(party_id) absorb(iso3n) reps($simrep_boot) coef(Dwagetax_pc_dec Dwagetax_rc_dec Dwagetax_pc_inc Dwagetax_rc_inc)
est save "results/estimates/wagetax_multi_r_pclust_2", replace

// testing alternative wage tax measures against eachother - standard errors 2
wildboot areg votechange Dwagetax_50_dec Dwagetax_200_dec Dwagetax_50_inc Dwagetax_200_inc $cntrl i.time_fe [w=cabparties_w], cluster(iso3n) absorb(iso3n) reps($simrep_boot) coef(Dwagetax_50_dec Dwagetax_200_dec Dwagetax_50_inc Dwagetax_200_inc)
est save "results/estimates/wagetax_multi_r_cclust_1", replace

wildboot areg votechange Dwagetax_pc_dec Dwagetax_rc_dec Dwagetax_pc_inc Dwagetax_rc_inc $cntrl i.time_fe [w=cabparties_w], cluster(iso3n) absorb(iso3n) reps($simrep_boot) coef(Dwagetax_pc_dec Dwagetax_rc_dec Dwagetax_pc_inc Dwagetax_rc_inc)
est save "results/estimates/wagetax_multi_r_cclust_2", replace

// testing alternative wage tax measures against eachother - collapsed dataset 
glob opts_collapsed $cntrl i.time_fe, cluster(iso3n) absorb(iso3n) reps($simrep_boot)
cap frame drop collapsed
frame create collapsed 
frame collapsed {
	use "data/processed/data_votechange_collapsed.dta", clear
	wildboot areg votechange Dwagetax_50_dec Dwagetax_200_dec Dwagetax_50_inc Dwagetax_200_inc $opts_collapsed 
	est save "results/estimates/wagetax_multi_r_collapse_1", replace
	wildboot areg votechange Dwagetax_pc_dec Dwagetax_rc_dec Dwagetax_pc_inc Dwagetax_rc_inc $opts_collapsed 
	est save "results/estimates/wagetax_multi_r_collapse_2", replace
}
frame drop collapsed


*---------------------------------------------------------------------------------------
* SUMMARY STATISTICS
*---------------------------------------------------------------------------------------

// summary statistics
outreg2 using "results/tables/sumstat.doc" [aw=cabparties_w], replace sum(log) eqkeep(N mean median sd min max) auto(2) label ///
	keep(votechange votechange_pc `xvarlist' `int' $cntrl ) sortvar(votechange votechange_pc `xvarlist' `int' $cntrl ) 
	
// additional statistics on included countries and years
cap program drop dsample
program dsample
syntax varlist
tokenize `varlist'
foreach i of numlist 1/20 {
	if "``i''"!="" {
		quietly {
			gdistinct iso3n if !mi(``i'')
			local ncountry = r(ndistinct)
			sum startyear if !mi(``i'')
			local minyear = r(min)
			sum endyear if !mi(``i'')
			local maxyear = r(max)
		}
		dis "------- ``i'' -------"
		dis "Countries: " `ncountry'
		dis "Years: " `minyear' " to " `maxyear'
	}
}
end

dsample RIpit RIvat Dwagetax_av Dvat Dtaxrevenue Dcorptax


*---------------------------------------------------------------------------------------
* CLEAN THE TABLE DIRECTORY
*---------------------------------------------------------------------------------------

preserve
filelist, dir("results/tables")
gen file = subinstr(filename, ".txt", "", .)
levelsof file if substr(filename,-3,3)=="txt", local(txtfiles)
restore
foreach x in `txtfiles' {
    erase "results/tables/`x'.txt"
}






















	



