clear all

*---------------------------------------------------------------------------------------
* LOAD DATA AND FIGURE OPTION PRESETS
*---------------------------------------------------------------------------------------

use "data/processed/data_votechange.dta",clear
run "code/99_figureoptions.do"


*---------------------------------------------------------------------------------------
* DESCRIPTIVE UNI- & BIVARIATE DISTRIBUTIONS
*---------------------------------------------------------------------------------------

// tax change distributions
gen cabparties_w_int = round(cabparties_w*100000)
global o $plottig title(,pos(11) span) xtitle("") nodraw xlab(#7) ylab(#5) bin(20)

hist RIpit [fw=cabparties_w_int], $mhistopts1 $o title("{bf:A}   Net PIT reforms") name(a,replace)
hist RIvat [fw=cabparties_w_int], $mhistopts2 $o title("{bf:B}   Net VAT reforms") name(b,replace)
hist Dwagetax_av [fw=cabparties_w_int], $mhistopts3 $o xlab(-15(5)15) title("{bf:C}   Wage tax rate change") name(c,replace)
hist Dvat [fw=cabparties_w_int], $mhistopts4 $o xlab(-6(3)9) title("{bf:D}   VAT rate change") name(d,replace)
graph combine a b c d, imargin(small) row(2) ysize(*1.2) scale(*1.6)
graph export "results/figures/reform_descriptives.emf", replace
graph export "results/figures/reform_descriptives.eps", replace

// scatterplots
glob o $plg_lfit2 scale(*1.3) nodraw legend(off) ytitle("Vote change (pp.)",size(*.9)) xtitle("") title(,pos(11) span) xline(0,lc(%70)) yline(0,lc(%70))
glob scattero jitter(2) msize(*.95)

tw (scatter votechange RIpit, $scattero $scatter35m1) (lfit votechange RIpit if RIpit<=0, $plg_mlfit1 ) (lfit votechange RIpit if RIpit>=0 [aw=cabparties_w], $plg_mlfit1 ), $o title("{bf:A}   Net PIT reforms") name(a,replace)
tw (scatter votechange RIvat, $scattero $scatter35m2) (lfit votechange RIvat if RIvat<=0, $plg_mlfit2 ) (lfit votechange RIvat if RIvat>=0 [aw=cabparties_w], $plg_mlfit2 ), $o title("{bf:B}   Net VAT reforms") name(b,replace)
tw (scatter votechange Dwagetax_av, $scattero $scatter35m3) (lfit votechange Dwagetax_av if Dwagetax_av<=0, $plg_darkmlfit3 ) (lfit votechange Dwagetax_av if Dwagetax_av>=0 [aw=cabparties_w], $plg_darkmlfit3 ), $o title("{bf:C}   Wage tax rate change") name(c,replace)
tw (scatter votechange Dvat, $scattero $scatter35m4) (lfit votechange Dvat if Dvat<=0, $plg_mlfit4 ) (lfit votechange Dvat if Dvat>=0 [aw=cabparties_w], $plg_mlfit4 ), $o title("{bf:D}   VAT rate change") name(d,replace)
graph combine a b c d, imargin(small) row(2) ysize(*1.1) scale(*1.1)
graph export "results/figures/scatterplots.emf", replace
graph export "results/figures/scatterplots.eps", replace


*---------------------------------------------------------------------------------------
* COEFFICIENT PLOTS
*---------------------------------------------------------------------------------------

// define program to build inputs for coefplot
cap program drop plothelper 
program plothelper 
	syntax , MODEL(string) Xvar(string)
	
	// file lister
	preserve
	qui filelist, dir("results/estimates")
	qui gen file = subinstr(filename, ".ster", "", .)
	qui sort file
	qui levelsof file if strpos(file,"`model'_`xvar'"), local(savedmodels)
	restore
	est clear
	local no = 0
	foreach x in `savedmodels' {
		dis " `x' "
		est use "results/estimates/`x'.ster"
		est sto `x'
		local no = `no'+1
	}
	
	// short-term models adaoption
	if `"`model'"'=="r_short" local xvar `xvar'_sh
	
	// model list 
	local count = 1
	glob plots (`model'_`xvar'_m1 , $m1 ) (`model'_`xvar'_m2 , $m2 )
	qui est dir
	foreach number of numlist 1/20 {
	    if strpos(r(names),"`model'_`xvar'_l`number'") & !((`"`model'"'=="r_onlyleft" & inlist(`number',3,4,5,6)) | ///
		(`"`model'"'=="r_onlyright" & inlist(`number',3,4,5,6)) | (`"`model'"'=="r_onlyclear" & inlist(`number',7,8))) {
			if mod(`count',2)==1 glob plots $plots (`model'_`xvar'_l`number' , $m1 )
			if mod(`count',2)==0 glob plots $plots (`model'_`xvar'_l`number' , $m2 )
			local count = `count'+1
		}
	}
	
	// further options
	*labels 
	glob labels `xvar' = "Overall change" `xvar'_inc = "Increase" `xvar'_dec = "Decrease" `xvar'_sh = "Overall change" `xvar'_sh_inc = "Increase" `xvar'_sh_dec = "Decrease"
	glob nolabels `xvar' = " " `xvar'_dec = " " `xvar'_inc = " "  `xvar'_sh = " " `xvar'_sh_inc = " " `xvar'_sh_dec = " "
	foreach numberi of numlist 1/20 {
		glob labels $labels `xvar'`numberi' = "Overall change" `xvar'_dec`numberi' = "Decrease" `xvar'_inc`numberi' = "Increase" ///
		`xvar'_sh`numberi' = "Overall change" `xvar'_sh_dec`numberi' = "Decrease" `xvar'_sh_inc`numberi' = "Increase"
		glob nolabels $nolabels `xvar'`numberi' = " " `xvar'_dec`numberi' = " " `xvar'_inc`numberi' = " " ///
		`xvar'_sh`numberi' = " " `xvar'_sh_dec`numberi' = " " `xvar'_sh_inc`numberi' = " "
	}
	*groups 
	#delimit ;
	glob groups 	`xvar' `xvar'_dec `xvar'_inc = "{bf:Overall}"
					`xvar'_sh `xvar'_sh_dec `xvar'_sh_inc = "{bf:Short-term}"
					`xvar'3 `xvar'_dec4 `xvar'_inc4 = `""{bf:Left}" "{bf:parties}""'
					`xvar'5 `xvar'_dec6 `xvar'_inc6 = `""{bf:Right}" "{bf:parties}""' 
					`xvar'7 `xvar'_dec8 `xvar'_inc8 = `""{bf:High clarity of}" "{bf:responsibility}""'
					`xvar'9 `xvar'_dec10 `xvar'_inc10 = `""{bf:High fiscal}" "{bf:pressure}""' ;
	
	glob nogroups 	`xvar' `xvar'_dec `xvar'_inc = " "
					`xvar'_sh `xvar'_sh_dec `xvar'_sh_inc = " "
					`xvar'3 `xvar'_dec4 `xvar'_inc4 = " "
					`xvar'5 `xvar'_dec6 `xvar'_inc6 = " "
					`xvar'7 `xvar'_dec8 `xvar'_inc8 = " "
					`xvar'9 `xvar'_dec10 `xvar'_inc10 = " " ;
	#delimit cr
	glob singlegroups $groups

	glob comboplot1 $cpopts groups($groups) coeflabel($labels) nodraw name(a,replace)
	glob comboplot2 $cpopts ylab(,notick)	groups($nogroups) coeflabel($nolabels) nodraw name(b,replace)
	glob singleplot $cpopts groups($singlegroups) coeflabel($labels) 
end

// coefplot options
*options for all graphs
glob cpopts keep(RIpi* RIva* Dwagetax* Dva* Dcorpta* Dtaxrevenu*) msize(*.8) level(95) $plg_coefplot legend(off) title(,size(*.8)) xlab(#6)
*size and scaling for the four different plot types
glob nogrcom xsize(*.8) scale(*1)
glob grcom xsize(*1) scale(*1.4) imargin(tiny)
glob s1 fxsize(145)
glob s2 fxsize(52)
*markers and CIs
glob m1 $cimarkers1 ciopts($cibars1) offset(0)
glob m2 $cimarkers2 ciopts($cibars2) offset(0)


// create figures with loop over all main and (most) robustness regressions
foreach model in mainspec r_nox r_pcdv r_time r_pclust r_cclust r_collapse { // r_onlyleft r_onlyright r_onlyclear
	
	* tax rate changes
	plothelper, model(`model') xvar(Dwagetax_av)
	coefplot $plots , $comboplot1 title("{bf:Wage tax}")
	plothelper, model(`model') xvar(Dvat)
	coefplot $plots , $comboplot2 $s2 title("{bf:Value-added tax}")
	graph combine a b, $grcom
	graph export "results/figures/`model'_wagetax.emf", replace
	graph export "results/figures/`model'_wagetax.eps", replace
	
	* reform events
	plothelper, model(`model') xvar(RIpit)
	coefplot $plots , $comboplot1 title("{bf:Personal income tax}")	
	plothelper, model(`model') xvar(RIvat)
	coefplot $plots , $comboplot2 $s2 title("{bf:Value-added tax}")
	graph combine a b, $grcom
	graph export "results/figures/`model'_reform.emf", replace
	graph export "results/figures/`model'_reform.eps", replace
}

// unwinsorized robustness check
plothelper, model(r_ogvars) xvar(Dwagetax_av_og)
coefplot $plots , $comboplot1 title("{bf:Wage tax}")
plothelper, model(r_ogvars) xvar(Dvat_og)
coefplot $plots , $comboplot2 $s2 title("{bf:Value-added tax}")
graph combine a b, $grcom
graph export "results/figures/r_ogvars_wagetax.emf", replace
graph export "results/figures/r_ogvars_wagetax.eps", replace
plothelper, model(r_ogvars) xvar(RIpit_og)
coefplot $plots , $comboplot1 title("{bf:Personal income tax}")	
plothelper, model(r_ogvars) xvar(RIvat_og)
coefplot $plots , $comboplot2 $s2 title("{bf:Value-added tax}")
graph combine a b, $grcom
graph export "results/figures/r_ogvars_reform.emf", replace
graph export "results/figures/r_ogvars_reform.eps", replace
	
// tax revenue and corporate taxation robustness check
plothelper, model(r_corprev) xvar(Dtaxrevenue)
coefplot $plots , $comboplot1 title("{bf:Tax revenue}")
plothelper, model(r_corprev) xvar(Dcorptax)
coefplot $plots , $comboplot2 $s2 title("{bf:Corporate taxation}")
graph combine a b, $grcom
graph export "results/figures/r_corprev_wagetax.emf", replace
graph export "results/figures/r_corprev_wagetax.eps", replace

plothelper, model(r_collapse) xvar(Dtaxrevenue)
coefplot $plots , $comboplot1 title("{bf:Tax revenue}")
plothelper, model(r_collapse) xvar(Dcorptax)
coefplot $plots , $comboplot2 $s2 title("{bf:Corporate taxation}")
graph combine a b, $grcom
graph export "results/figures/r_corprev_wagetax_coll.emf", replace
graph export "results/figures/r_corprev_wagetax_coll.eps", replace

	
*---------------------------------------------------------------------------------------
* DISAGGREGATED WAGE TAX RATE MODELS
*---------------------------------------------------------------------------------------

// build different version of the plothelper program
cap program drop plothelper 
program plothelper 
	syntax , MODEL(string) Xvar(string)
	
	// file lister
	preserve
	qui filelist, dir("results/estimates")
	qui gen file = subinstr(filename, ".ster", "", .)
	qui sort file
	qui levelsof file if strpos(file,"`model'_`xvar'"), local(savedmodels)
	restore
	est clear
	local no = 0
	foreach x in `savedmodels' {
		dis " `x' "
		est use "results/estimates/`x'.ster"
		est sto `x'
		local no = `no'+1
	}
	
	// model list 
	glob plots (`model'_`xvar'_m1 , $m1 ) (`model'_`xvar'_m2 , $m2 )

	// further options
	*labels 
	glob labels `xvar' = "Overall change" `xvar'_inc = "Increase" `xvar'_dec = "Decrease"
	glob nolabels `xvar' = " " `xvar'_dec = " " `xvar'_inc = " "

	glob comboplot1 $cpopts coeflabel($labels) nodraw
	glob comboplot2 $cpopts ylab(,notick) coeflabel($nolabels) nodraw
	glob singleplot $cpopts coeflabel($labels) 
end

// coefplot options
*options for all graphs
glob cpopts keep(RIpi* RIva* Dwagetax* Dva* Dcorpta* Dtaxrevenu*) msize(*.8) level(95) $plg_coefplot legend(off) title(,size(*.8)) xlab(-.8(.4).8) xsc(r(-.85 .85))
*size and scaling for the four different plot types
glob nogrcom xsize(*.8) scale(*1)
glob grcom imargin(tiny) row(1) nodraw
glob grcom2 imargin(tiny) row(2) scale(*2.8) ysize(*.7)
glob s1 fxsize(138)
glob s2 fxsize(57)
*markers and CIs
glob m1 $cimarkers1 ciopts($cibars1) offset(0)
glob m2 $cimarkers2 ciopts($cibars2) offset(0)

// create plots
plothelper, model(altrates) xvar(Dwagetax_50)
coefplot $plots , $comboplot1 name(a,replace) title("{bf:50% earnings single}")
plothelper, model(altrates) xvar(Dwagetax_100)
coefplot $plots , $comboplot2 $s2 name(b,replace) title("{bf:100% earnings single}")
plothelper, model(altrates) xvar(Dwagetax_150)
coefplot $plots , $comboplot2 $s2 name(c,replace) title("{bf:150% earnings single}")
graph combine a b c, $grcom name(x, replace)
plothelper, model(altrates) xvar(Dwagetax_200)
coefplot $plots , $comboplot1 name(a,replace) title("{bf:200% earnings single}")
plothelper, model(altrates) xvar(Dwagetax_pc)
coefplot $plots , $comboplot2 $s2 name(b,replace) title("{bf:50%-50% couple}")
plothelper, model(altrates) xvar(Dwagetax_rc)
coefplot $plots , $comboplot2 $s2 name(c,replace) title("{bf:150%-150% couple}")
graph combine a b c, $grcom name(y, replace)
graph combine x y, $grcom2 
graph export "results/figures/wagetax_disaggregated.emf", replace
graph export "results/figures/wagetax_disaggregated.eps", replace


*---------------------------------------------------------------------------------------
* TOP vs BOTTOM EFFECTIVE WAGE TAX CHANGE ANALYSIS
*---------------------------------------------------------------------------------------

// options
glob cpopts keep(RIpi* RIva* Dwagetax* Dva* Dcorpta* Dtaxrevenu*) msize(*.8) level(95) $plg_coefplot legend(off) title(,size(*.8))
glob grcomboopts col(2) iscale(*2.65) ysize(*.5) imargin(small) 
global cntrl days vote_share effnum_party unemp_avg Dunemp realgdpgr_avg Drealgdpgr deficit_y1
global modelopts 	cluster(gov_id) absorb(iso3n) reps($simrep_boot)

// import model results
est clear
foreach x in 1 2 {
	foreach version in "" _r_av_ _r_pcdv_ _r_pclust_ _r_cclust_ _r_collapse_ {
		dis "wagetax_multi`version'`x'"
		est use "results/estimates/wagetax_multi`version'`x'.ster"
		est sto wagetax_multi`version'`x'
	}
}

// create variables that contain coordinates for added lines to coefplot
cap program drop genhlp
program genhlp
	syntax, left(string) top(string) dv(string) [collapsed]
	if "`dv'"=="votechange" local xval = .7
	if "`dv'"=="votechange_pc" local xval = 2.2
	if "`collapsed'"!="" local xval = 1.05
	if "`top'"=="yes" local yval1 = 1.1
	if "`top'"=="yes" local yval2 = 1.9
	if "`top'"!="yes" local yval1 = 3.8 //4.1
	if "`top'"!="yes" local yval2 = 4.6 //4.9

	local one = 1
	local two = 2 
	local three = 3 
	foreach zz in one two three {
		if "`top'"!="yes" local `zz' = ``zz''+3
	}
	local xval_offset = `xval'-.05

	if "`left'"=="yes" local lr 1
	if "`left'"!="yes" local lr 2

	* naming convetion: x_leftright_welcherderdreistriche_koordinate1oder2
	* main line
	gen y_`lr'_`one'_1_`dv' = `yval1' in 1
	gen x_`lr'_`one'_1_`dv' = `xval' in 1
	gen y_`lr'_`one'_2_`dv' = `yval2' in 1
	gen x_`lr'_`one'_2_`dv' = `xval' in 1
	* top hook
	gen y_`lr'_`two'_1_`dv' = `yval1' in 1
	gen x_`lr'_`two'_1_`dv' = `xval_offset' in 1
	gen y_`lr'_`two'_2_`dv' = `yval1' in 1
	gen x_`lr'_`two'_2_`dv' = `xval' in 1
	* bottom hook
	gen y_`lr'_`three'_1_`dv' = `yval2' in 1
	gen x_`lr'_`three'_1_`dv' = `xval_offset' in 1
	gen y_`lr'_`three'_2_`dv' = `yval2' in 1
	gen x_`lr'_`three'_2_`dv' = `xval' in 1
end

cap drop y_* x_*
foreach depvar in votechange votechange_pc {
	foreach yesno1 in yes no {
		foreach yesno2 in yes no {
			genhlp, top(`yesno1') left(`yesno2') dv(`depvar')
		}
	}
}

// prepare command input for added lines & signifinance stars 
cap program drop addplothelp
program addplothelp
	syntax , dv(string) modelopts(string) left(string) collapsed(string) [avcomp]
	preserve
	if "`left'"=="yes" local lr 1
	if "`left'"!="yes" local lr 2

	local ap addplot(
	foreach i of numlist 1/6 {
		local ap `ap' pcspike y_`lr'_`i'_1_`dv' x_`lr'_`i'_1_`dv' y_`lr'_`i'_2_`dv' x_`lr'_`i'_2_`dv', lw(thin) lc(gs4)
		if `i'!=6 local ap `ap' || 
		
	}
	glob ap `ap')

	if "`left'"=="yes" {
		if "`avcomp'"=="" local onh 200
		if "`avcomp'"!="" local onh 100
		
		if "`collapsed'"!="yes" {
			local xval .75
			wildboot areg `dv' Dwagetax_50_dec Dwagetax_`onh'_dec Dwagetax_50_inc Dwagetax_`onh'_inc $cntrl i.time_fe [aw=cabparties_w], `modelopts' ///
			test((Dwagetax_50_dec=Dwagetax_`onh'_dec) (Dwagetax_50_inc=Dwagetax_`onh'_inc))
		}
		if "`collapsed'"=="yes" {
			local xval 1.1
			use "data/processed/data_votechange_collapsed.dta", clear
			wildboot areg `dv' Dwagetax_50_dec Dwagetax_`onh'_dec Dwagetax_50_inc Dwagetax_`onh'_inc $cntrl i.time_fe, `modelopts' ///
			test((Dwagetax_50_dec=Dwagetax_`onh'_dec) (Dwagetax_50_inc=Dwagetax_`onh'_inc))
		}
	}
	if "`left'"!="yes" {
		if "`avcomp'"=="" local onh rc
		if "`avcomp'"!="" local onh ac
		
		if "`collapsed'"!="yes" {
			local xval .75
			wildboot areg `dv' Dwagetax_pc_dec Dwagetax_`onh'_dec Dwagetax_pc_inc Dwagetax_`onh'_inc $cntrl i.time_fe [aw=cabparties_w], `modelopts' ///
			test((Dwagetax_pc_dec=Dwagetax_`onh'_dec) (Dwagetax_pc_inc=Dwagetax_`onh'_inc))
		}
		if "`collapsed'"=="yes" {
			local xval 1.1
			use "data/processed/data_votechange_collapsed.dta", clear
			wildboot areg `dv' Dwagetax_pc_dec Dwagetax_`onh'_dec Dwagetax_pc_inc Dwagetax_`onh'_inc $cntrl i.time_fe, `modelopts' ///
			test((Dwagetax_pc_dec=Dwagetax_`onh'_dec) (Dwagetax_pc_inc=Dwagetax_`onh'_inc))
		}
	}

	foreach pval of numlist 1 2 {
		local p`pval' = r(table)[3,`pval']
	}
	foreach pval of numlist 1 2 {
		local pval`pval'
		if `p`pval''<.1 & `p`pval''>=.05 local pval`pval' *
		if `p`pval''<.05 & `p`pval''>=.01 local pval`pval' **
		if `p`pval''<.01 local pval`pval' ***
	}

	local text1 `"text(1.6 `xval' "`pval1'",placement(3) size(*.82))"'
	local text2 `"text(4.3 `xval' "`pval2'",placement(3) size(*.82))"'
	glob text `" `text1' `text2' "'
	
	restore
end

// draw the coefficient plots
addplothelp, left(yes) dv(votechange) modelopts($modelopts) collapsed(no)
coefplot (wagetax_multi1, $m1 ) , $cpopts xlab(-1.2(.4).8) xsc(r(-1.3 .9)) title("{bf:Model 1: Singles}") name(a,replace) nodraw ///
coeflabel(Dwagetax_50_dec="50% earnings" Dwagetax_200_dec="200% earnings" Dwagetax_50_inc="50% earnings" Dwagetax_200_inc="      200% earnings") ///
groups(Dwagetax_50_dec Dwagetax_200_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_50_inc Dwagetax_200_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

addplothelp, left(no) dv(votechange) modelopts($modelopts) collapsed(no)
coefplot (wagetax_multi2, $m2 ) , $cpopts xlab(-1.2(.4).8) xsc(r(-1.3 .9)) title("{bf:Model 2: Couples}") name(b,replace) nodraw ///
coeflabel(Dwagetax_pc_dec="50%-50% earnings" Dwagetax_rc_dec="150%-150% earnings" Dwagetax_pc_inc="50%-50% earnings" Dwagetax_rc_inc="150%-150% earnings") ///
groups(Dwagetax_pc_dec Dwagetax_rc_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_pc_inc Dwagetax_rc_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

gr combine a b, $grcomboopts
graph export "results/figures/wagetax_combinedmodel.emf", replace
graph export "results/figures/wagetax_combinedmodel.eps", replace

// robustness - comparison to average
addplothelp, left(yes) dv(votechange) modelopts($modelopts) collapsed(no) avcomp
coefplot (wagetax_multi_r_av_1, $m1 ) , $cpopts xlab(-1.2(.4).8) xsc(r(-1.3 .9)) title("{bf:Model 1: Singles}") name(a,replace) nodraw ///
coeflabel(Dwagetax_50_dec="50% earnings" Dwagetax_100_dec="100% earnings" Dwagetax_50_inc="50% earnings" Dwagetax_100_inc="      100% earnings") ///
groups(Dwagetax_50_dec Dwagetax_100_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_50_inc Dwagetax_100_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

addplothelp, left(no) dv(votechange) modelopts($modelopts) collapsed(no) avcomp
coefplot (wagetax_multi_r_av_2, $m2 ) , $cpopts xlab(-1.2(.4).8) xsc(r(-1.3 .9)) title("{bf:Model 2: Couples}") name(b,replace) nodraw ///
coeflabel(Dwagetax_pc_dec="50%-50% earnings" Dwagetax_ac_dec="150%-50% earnings" Dwagetax_pc_inc="50%-50% earnings" Dwagetax_ac_inc="150%-50% earnings") ///
groups(Dwagetax_pc_dec Dwagetax_ac_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_pc_inc Dwagetax_ac_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

gr combine a b, $grcomboopts
graph export "results/figures/wagetax_combinedmodel_r_av.emf", replace
graph export "results/figures/wagetax_combinedmodel_r_av.eps", replace

// robustness - party clustered SEs
addplothelp, left(yes) dv(votechange) modelopts(cluster(party_id) absorb(iso3n) reps($simrep_boot)) collapsed(no)
coefplot (wagetax_multi_r_pclust_1, $m1 ) , $cpopts xlab(-1.2(.4).8) xsc(r(-1.3 .9)) title("{bf:Model 1: Singles}") name(a,replace) nodraw ///
coeflabel(Dwagetax_50_dec="50% earnings" Dwagetax_200_dec="200% earnings" Dwagetax_50_inc="50% earnings" Dwagetax_200_inc="      200% earnings") ///
groups(Dwagetax_50_dec Dwagetax_200_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_50_inc Dwagetax_200_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

addplothelp, left(no) dv(votechange) modelopts(cluster(party_id) absorb(iso3n) reps($simrep_boot)) collapsed(no)
coefplot (wagetax_multi_r_pclust_2, $m2 ) , $cpopts xlab(-1.2(.4).8) xsc(r(-1.3 .9)) title("{bf:Model 2: Couples}") name(b,replace) nodraw ///
coeflabel(Dwagetax_pc_dec="50%-50% earnings" Dwagetax_rc_dec="150%-150% earnings" Dwagetax_pc_inc="50%-50% earnings" Dwagetax_rc_inc="150%-150% earnings") ///
groups(Dwagetax_pc_dec Dwagetax_rc_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_pc_inc Dwagetax_rc_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

gr combine a b, $grcomboopts
graph export "results/figures/wagetax_combinedmodel_r_pclust.emf", replace
graph export "results/figures/wagetax_combinedmodel_r_pclust.eps", replace

// robustness - country clustered SEs
addplothelp, left(yes) dv(votechange) modelopts(cluster(iso3n) absorb(iso3n) reps($simrep_boot)) collapsed(no)
coefplot (wagetax_multi_r_cclust_1, $m1 ) , $cpopts xlab(-1.2(.4).8) xsc(r(-1.3 .9)) title("{bf:Model 1: Singles}") name(a,replace) nodraw ///
coeflabel(Dwagetax_50_dec="50% earnings" Dwagetax_200_dec="200% earnings" Dwagetax_50_inc="50% earnings" Dwagetax_200_inc="      200% earnings") ///
groups(Dwagetax_50_dec Dwagetax_200_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_50_inc Dwagetax_200_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

addplothelp, left(no) dv(votechange) modelopts(cluster(iso3n) absorb(iso3n) reps($simrep_boot)) collapsed(no)
coefplot (wagetax_multi_r_cclust_2, $m2 ) , $cpopts xlab(-1.2(.4).8) xsc(r(-1.3 .9)) title("{bf:Model 2: Couples}") name(b,replace) nodraw ///
coeflabel(Dwagetax_pc_dec="50%-50% earnings" Dwagetax_rc_dec="150%-150% earnings" Dwagetax_pc_inc="50%-50% earnings" Dwagetax_rc_inc="150%-150% earnings") ///
groups(Dwagetax_pc_dec Dwagetax_rc_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_pc_inc Dwagetax_rc_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

gr combine a b, $grcomboopts
graph export "results/figures/wagetax_combinedmodel_r_cclust.emf", replace
graph export "results/figures/wagetax_combinedmodel_r_cclust.eps", replace

// robustness - collapsed data
cap drop y_* x_*
foreach depvar in votechange {
	foreach yesno1 in yes no {
		foreach yesno2 in yes no {
			genhlp, top(`yesno1') left(`yesno2') dv(`depvar') collapsed
		}
	}
}

addplothelp, left(yes) dv(votechange) modelopts(cluster(iso3n) absorb(iso3n) reps($simrep_boot)) collapsed(yes)
coefplot (wagetax_multi_r_collapse_1, $m1 ) , $cpopts xlab(-1.5(.5)1) xsc(r(-1.7 1.2)) title("{bf:Model 1: Singles}") name(a,replace) nodraw ///
coeflabel(Dwagetax_50_dec="50% earnings" Dwagetax_200_dec="200% earnings" Dwagetax_50_inc="50% earnings" Dwagetax_200_inc="      200% earnings") ///
groups(Dwagetax_50_dec Dwagetax_200_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_50_inc Dwagetax_200_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

addplothelp, left(no) dv(votechange) modelopts(cluster(iso3n) absorb(iso3n) reps($simrep_boot)) collapsed(yes)
coefplot (wagetax_multi_r_collapse_2, $m2 ) , $cpopts xlab(-1.5(.5)1) xsc(r(-1.7 1.2)) title("{bf:Model 2: Couples}") name(b,replace) nodraw ///
coeflabel(Dwagetax_pc_dec="50%-50% earnings" Dwagetax_rc_dec="150%-150% earnings" Dwagetax_pc_inc="50%-50% earnings" Dwagetax_rc_inc="150%-150% earnings") ///
groups(Dwagetax_pc_dec Dwagetax_rc_dec=`""{bf:Tax}" "{bf:decreases}""' Dwagetax_pc_inc Dwagetax_rc_inc=`""{bf:Tax}" "{bf:increases}""',angle(vert) gap(.7)) $ap $text

gr combine a b, $grcomboopts
graph export "results/figures/wagetax_combinedmodel_r_collapse.emf", replace
graph export "results/figures/wagetax_combinedmodel_r_collapse.eps", replace


*---------------------------------------------------------------------------------------
* EFFECT HETEROGENEITY BY PARTY SIZE
*---------------------------------------------------------------------------------------

glob cntrl2 days effnum_party unemp_avg Dunemp realgdpgr_avg Drealgdpgr deficit_y1 debt_y1
glob opts2 fc(iso3n time_fe) vce(wbcluster gov_id) ci indslopesci scale(*1.3) xysize(*1.85) nq(6)
foreach var in RIpit RIvat Dwagetax_av Dvat {
	slopefit votechange `var'_inc vote_share [aw=cabparties_w], c(`var'_dec $cntrl2) $opts2
	graph export "results/figures/slopefit_`var'_inc.emf", replace
	graph export "results/figures/slopefit_`var'_inc.eps", replace
	slopefit votechange `var'_dec vote_share [aw=cabparties_w], c(`var'_inc $cntrl2) $opts2
	graph export "results/figures/slopefit_`var'_dec.emf", replace
	graph export "results/figures/slopefit_`var'_dec.eps", replace
}
































